<?php

declare(strict_types=1);

namespace App\Controller;

use App\Entity\SystemConfig;
use App\Enum\SystemSettingKey;
use App\Form\SystemConfigForm;
use App\Repository\SystemConfigRepository;
use App\Service\ConfigurationService;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/system-config')]
final class SystemConfigController extends AbstractController
{
    #[Route(name: 'app_system_config_index', methods: ['GET'])]
    public function index(SystemConfigRepository $systemConfigRepository): Response
    {
        $configs = [];
        foreach (SystemSettingKey::cases() as $key) {
            $configs[] = $systemConfigRepository->findByKey($key);
        }

        return $this->render('system_config/index.html.twig', [
            'system_configs' => $configs,
        ]);
    }

    #[Route(path: '/{id}/edit', name: 'app_system_config_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, SystemConfig $systemConfig, EntityManagerInterface $entityManager): Response
    {
        $form = $this->createForm(SystemConfigForm::class, $systemConfig);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->flush();

            return $this->redirectToRoute('app_system_config_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('system_config/edit.html.twig', [
            'system_config' => $systemConfig,
            'form' => $form,
        ]);
    }

    #[Route(path: '/{id}/reset', name: 'app_system_config_reset', methods: ['POST'])]
    public function reset(Request $request, SystemConfig $systemConfig, ConfigurationService $configurationService): Response
    {
        if ($this->isCsrfTokenValid('reset' . $systemConfig->getId(), $request->getPayload()->getString('_token'))) {
            $configurationService->reset($systemConfig->getKey());
        }

        return $this->redirectToRoute('app_system_config_index', [], Response::HTTP_SEE_OTHER);
    }
}
