<?php

declare(strict_types=1);

namespace App\Service\DrinkType;

use App\Entity\DrinkType;
use App\Entity\Order;
use App\Entity\OrderItem;
use App\Repository\DrinkTypeRepository;
use Doctrine\Common\Collections\ArrayCollection;

final readonly class CreateNewOrderItems
{
    public function __construct(
        private DrinkTypeRepository $drinkTypeRepository,
    ) {}

    public function __invoke(Order $order): void
    {
        new ArrayCollection($this->drinkTypeRepository->findWanted())->forAll(
            function (int $index, DrinkType $drinkType) use ($order): true {
                $quantity = $drinkType->getWantedStock() - $drinkType->getCurrentStock();
                if ($quantity > 0) {
                    $order->addOrderItem(
                        new OrderItem()
                            ->setDrinkType($drinkType)
                            ->setQuantity($quantity)
                    );
                }
                return true; // Required for forAll to continue iterating
            }
        );
    }
}
